@@ -17,11 +17,17 @@ _CURRENT = local()
 _THOUSANDS_SEPARATOR = {
     "de_DE": ".",
     "fr_FR": " ",
+    "it_IT": ".",
+    "pt_BR": ".",
+    "hu_HU": " ",
 }
 
 # Mapping of locale to decimal separator
 _DECIMAL_SEPARATOR = {
     "de_DE": ",",
+    "it_IT": ",",
+    "pt_BR": ",",
+    "hu_HU": ",",
 }
 
 
@@ -60,10 +66,11 @@ def activate(locale: str, path: str | None = None) -> gettext_module.NullTransla
         path = _get_default_locale_path()
 
     if path is None:
-        raise Exception(
+        msg = (
             "Humanize cannot determinate the default location of the 'locale' folder. "
             "You need to pass the path explicitly."
         )
+        raise Exception(msg)
     if locale not in _TRANSLATIONS:
         translation = gettext_module.translation("humanize", path, [locale])
         _TRANSLATIONS[locale] = translation
@@ -101,16 +108,7 @@ def _pgettext(msgctxt: str, message: str) -> str:
     Returns:
         str: Translated text.
     """
-    # This GNU gettext function was added in Python 3.8, so for older versions we
-    # reimplement it. It works by joining `msgctx` and `message` by '4' byte.
-    try:
-        # Python 3.8+
-        return get_translation().pgettext(msgctxt, message)
-    except AttributeError:
-        # Python 3.7 and older
-        key = msgctxt + "\x04" + message
-        translation = get_translation().gettext(key)
-        return message if translation == key else translation
+    return get_translation().pgettext(msgctxt, message)
 
 
 def _ngettext(message: str, plural: str, num: int) -> str:
