@@ -1,4 +1,6 @@
 """Internationalisation tests."""
+from __future__ import annotations
+
 import datetime as dt
 import importlib
 
@@ -53,6 +55,9 @@ def test_intcomma() -> None:
         humanize.i18n.activate("fr_FR")
         assert humanize.intcomma(number) == "10 000 000"
 
+        humanize.i18n.activate("pt_BR")
+        assert humanize.intcomma(number) == "10.000.000"
+
     except FileNotFoundError:
         pytest.skip("Generate .mo with scripts/generate-translation-binaries.sh")
 
