@@ -36,6 +36,9 @@ class FakeDate:
     def __init__(self, year: int, month: int, day: int) -> None:
         self.year, self.month, self.day = year, month, day
 
+    def __str__(self) -> str:
+        return f"{self.year}-{self.month}-{self.day}"
+
 
 VALUE_ERROR_TEST = FakeDate(290149024, 2, 2)
 OVERFLOW_ERROR_TEST = FakeDate(120390192341, 2, 2)
@@ -71,10 +74,6 @@ def test_date_and_delta() -> None:
 # Tests for the public interface of humanize.time
 
 
-def nd_nomonths(d: dt.timedelta) -> str:
-    return humanize.naturaldelta(d, months=False)
-
-
 @pytest.mark.parametrize(
     "test_input, expected",
     [
@@ -85,7 +84,7 @@ def nd_nomonths(d: dt.timedelta) -> str:
     ],
 )
 def test_naturaldelta_nomonths(test_input: dt.timedelta, expected: str) -> None:
-    assert nd_nomonths(test_input) == expected
+    assert humanize.naturaldelta(test_input, months=False) == expected
 
 
 @pytest.mark.parametrize(
@@ -170,10 +169,6 @@ def test_naturaltime(test_input: dt.datetime, expected: str) -> None:
     assert humanize.naturaltime(test_input) == expected
 
 
-def nt_nomonths(d: dt.datetime) -> str:
-    return humanize.naturaltime(d, months=False)
-
-
 @freeze_time("2020-02-02")
 @pytest.mark.parametrize(
     "test_input, expected",
@@ -212,7 +207,7 @@ def nt_nomonths(d: dt.datetime) -> str:
     ],
 )
 def test_naturaltime_nomonths(test_input: dt.datetime, expected: str) -> None:
-    assert nt_nomonths(test_input) == expected
+    assert humanize.naturaltime(test_input, months=False) == expected
 
 
 @freeze_time("2020-02-02")
@@ -415,6 +410,74 @@ def test_naturaltime_minimum_unit_explicit(
     assert humanize.naturaltime(datetime, minimum_unit=minimum_unit) == expected
 
 
+@freeze_time("2020-02-02")
+@pytest.mark.parametrize(
+    "test_input, expected",
+    [
+        (NOW_UTC, "now"),
+        (NOW_UTC - dt.timedelta(seconds=1), "a second ago"),
+        (NOW_UTC - dt.timedelta(seconds=30), "30 seconds ago"),
+        (NOW_UTC - dt.timedelta(minutes=1, seconds=30), "a minute ago"),
+        (NOW_UTC - dt.timedelta(minutes=2), "2 minutes ago"),
+        (NOW_UTC - dt.timedelta(hours=1, minutes=30, seconds=30), "an hour ago"),
+        (NOW_UTC - dt.timedelta(hours=23, minutes=50, seconds=50), "23 hours ago"),
+        (NOW_UTC - dt.timedelta(days=1), "a day ago"),
+        (NOW_UTC - dt.timedelta(days=500), "1 year, 4 months ago"),
+        (NOW_UTC - dt.timedelta(days=365 * 2 + 35), "2 years ago"),
+        (NOW_UTC + dt.timedelta(seconds=1), "a second from now"),
+        (NOW_UTC + dt.timedelta(seconds=30), "30 seconds from now"),
+        (NOW_UTC + dt.timedelta(minutes=1, seconds=30), "a minute from now"),
+        (NOW_UTC + dt.timedelta(minutes=2), "2 minutes from now"),
+        (NOW_UTC + dt.timedelta(hours=1, minutes=30, seconds=30), "an hour from now"),
+        (NOW_UTC + dt.timedelta(hours=23, minutes=50, seconds=50), "23 hours from now"),
+        (NOW_UTC + dt.timedelta(days=1), "a day from now"),
+        (NOW_UTC + dt.timedelta(days=500), "1 year, 4 months from now"),
+        (NOW_UTC + dt.timedelta(days=365 * 2 + 35), "2 years from now"),
+        # regression tests for bugs in post-release humanize
+        (NOW_UTC + dt.timedelta(days=10000), "27 years from now"),
+        (NOW_UTC - dt.timedelta(days=365 + 35), "1 year, 1 month ago"),
+        (NOW_UTC - dt.timedelta(days=365 * 2 + 65), "2 years ago"),
+        (NOW_UTC - dt.timedelta(days=365 + 4), "1 year, 4 days ago"),
+    ],
+)
+def test_naturaltime_timezone(test_input: dt.datetime, expected: str) -> None:
+    assert humanize.naturaltime(test_input) == expected
+
+
+@freeze_time("2020-02-02")
+@pytest.mark.parametrize(
+    "test_input, expected",
+    [
+        (NOW_UTC, "now"),
+        (NOW_UTC - dt.timedelta(seconds=1), "a second ago"),
+        (NOW_UTC - dt.timedelta(seconds=30), "30 seconds ago"),
+        (NOW_UTC - dt.timedelta(minutes=1, seconds=30), "a minute ago"),
+        (NOW_UTC - dt.timedelta(minutes=2), "2 minutes ago"),
+        (NOW_UTC - dt.timedelta(hours=1, minutes=30, seconds=30), "an hour ago"),
+        (NOW_UTC - dt.timedelta(hours=23, minutes=50, seconds=50), "23 hours ago"),
+        (NOW_UTC - dt.timedelta(days=1), "a day ago"),
+        (NOW_UTC - dt.timedelta(days=500), "1 year, 4 months ago"),
+        (NOW_UTC - dt.timedelta(days=365 * 2 + 35), "2 years ago"),
+        (NOW_UTC + dt.timedelta(seconds=1), "a second from now"),
+        (NOW_UTC + dt.timedelta(seconds=30), "30 seconds from now"),
+        (NOW_UTC + dt.timedelta(minutes=1, seconds=30), "a minute from now"),
+        (NOW_UTC + dt.timedelta(minutes=2), "2 minutes from now"),
+        (NOW_UTC + dt.timedelta(hours=1, minutes=30, seconds=30), "an hour from now"),
+        (NOW_UTC + dt.timedelta(hours=23, minutes=50, seconds=50), "23 hours from now"),
+        (NOW_UTC + dt.timedelta(days=1), "a day from now"),
+        (NOW_UTC + dt.timedelta(days=500), "1 year, 4 months from now"),
+        (NOW_UTC + dt.timedelta(days=365 * 2 + 35), "2 years from now"),
+        # regression tests for bugs in post-release humanize
+        (NOW_UTC + dt.timedelta(days=10000), "27 years from now"),
+        (NOW_UTC - dt.timedelta(days=365 + 35), "1 year, 1 month ago"),
+        (NOW_UTC - dt.timedelta(days=365 * 2 + 65), "2 years ago"),
+        (NOW_UTC - dt.timedelta(days=365 + 4), "1 year, 4 days ago"),
+    ],
+)
+def test_naturaltime_timezone_when(test_input: dt.datetime, expected: str) -> None:
+    assert humanize.naturaltime(test_input, when=NOW_UTC) == expected
+
+
 @pytest.mark.parametrize(
     "val, min_unit, expected",
     [
